@@ -5,11 +5,11 @@ import warnings
 import functools
 from typing import Optional
 
-
 try:
     import cbitstruct as bitstruct
 except ImportError:
     import bitstruct
+
     try:
         import bitstruct.c
     except ImportError:
@@ -23,31 +23,37 @@ from .enums import EBaseUnits, EByteOrder
 from .codecs import has_codec, get_codec
 from .descriptors import field_descriptors
 
-
 __all__ = [
-    'Decoder', 'decoder', 'Encoder', 'encoder', 'Codec', 'codec',
-    'BACKEND_NAME', 'BACKEND_TYPE',
-    'packbits', 'unpackbits',
+    "Decoder",
+    "decoder",
+    "Encoder",
+    "encoder",
+    "Codec",
+    "codec",
+    "BACKEND_NAME",
+    "BACKEND_TYPE",
+    "packbits",
+    "unpackbits",
 ]
 
 
-BACKEND_NAME = 'bitstruct'
+BACKEND_NAME = "bitstruct"
 BACKEND_TYPE = EBaseUnits.BITS
 
 
 class BitStruct:
     @staticmethod
-    def _simplified_fmt(format: str) -> Optional[str]:
-        fmt = format.replace('>', '')
-        if '<' in fmt:
+    def _simplified_fmt(format_: str) -> Optional[str]:
+        fmt = format_.replace(">", "")
+        if "<" in fmt:
             return None
         else:
             return fmt
 
-    def __init__(self, format: str, names=None):                        # noqa
+    def __init__(self, format_: str, names=None):
         codec_ = None
-        if hasattr(bitstruct, 'c'):
-            fmt = self._simplified_fmt(format)
+        if hasattr(bitstruct, "c"):
+            fmt = self._simplified_fmt(format_)
             if fmt is not None:
                 try:
                     codec_ = bitstruct.c.compile(fmt, names)
@@ -55,13 +61,13 @@ class BitStruct:
                     pass
 
         if codec_ is None:
-            codec_ = bitstruct.compile(format, names)
+            codec_ = bitstruct.compile(format_, names)
 
         self._bitstruct = codec_
-        self._format: str = format
+        self._format: str = format_
 
     @property
-    def format(self) -> str:
+    def format(self) -> str:  # noqa: A003
         return self._format
 
     def __getattr__(self, name):
@@ -69,40 +75,47 @@ class BitStruct:
 
 
 _TYPE_TO_STR = {
-    bool: 'b',
-    int: 'u',
-    (int, False): 'u',
-    (int, True): 's',
-    float: 'f',
-    bytes: 'r',
-    str: 't',
-    None: 'p',
+    bool: "b",
+    int: "u",
+    (int, False): "u",
+    (int, True): "s",
+    float: "f",
+    bytes: "r",
+    str: "t",
+    None: "p",
 }
 
 
 def _format_string_without_order(fmt: str, order: str) -> str:
     # NOTE: in the current implementation the byte order is handled
     #       externally to _to_fmt
-    if order != '':
+    if order != "":
         fmt = fmt[:-1] if fmt.endswith(order) else fmt
     return fmt
 
 
-def _to_fmt(type_, size: int, bitorder: str = '', byteorder: str = '',
-            signed: Optional[bool] = None,
-            repeat: Optional[int] = None) -> str:
-    assert size > 0, f'invalid size: {size:r}'
-    assert bitorder in ('', '>', '<'), f'invalid order: {bitorder:r}'
+def _to_fmt(
+    type_,
+    size: int,
+    bitorder: str = "",
+    byteorder: str = "",
+    signed: Optional[bool] = None,
+    repeat: Optional[int] = None,
+) -> str:
+    assert size > 0, f"invalid size: {size:r}"
+    assert bitorder in ("", ">", "<"), f"invalid order: {bitorder:r}"
     if repeat is None:
         repeat = 1
-    assert repeat > 0, f'invalid repeat: {repeat:r}'
+    assert repeat > 0, f"invalid repeat: {repeat:r}"
 
     if has_codec(type_, bpack.codecs.Decoder):
         decoder_ = get_codec(type_)
         if isinstance(decoder_, Decoder):
             return _format_string_without_order(decoder_.format, byteorder)
-    elif (bpack.is_descriptor(type_) and
-          bpack.baseunits(type_) is Decoder.baseunits):
+    elif (
+        bpack.is_descriptor(type_)
+        and bpack.baseunits(type_) is Decoder.baseunits
+    ):
         decoder_ = Decoder(type_)
         return _format_string_without_order(decoder_.format, byteorder)
 
@@ -110,9 +123,9 @@ def _to_fmt(type_, size: int, bitorder: str = '', byteorder: str = '',
     key = (etype, signed) if etype is int and signed is not None else etype
 
     try:
-        fmt = f'{bitorder}{_TYPE_TO_STR[key]}{size}' * repeat           # noqa
+        fmt = f"{bitorder}{_TYPE_TO_STR[key]}{size}" * repeat
     except KeyError:
-        raise TypeError(f'unsupported type: {etype:!r}')
+        raise TypeError(f"unsupported type: {etype:!r}")
 
     # fmt += byteorder  # NOTE: handled externally
 
@@ -139,10 +152,15 @@ class Codec(bpack.codecs.BaseStructCodec):
         byteorder = _endianess_to_str(byteorder)
         bitorder = bpack.bitorder(descriptor).value
 
-        fmt = ''.join(
-            _to_fmt(field_descr.type, size=field_descr.size, bitorder=bitorder,
-                    byteorder=byteorder, signed=field_descr.signed,
-                    repeat=field_descr.repeat)
+        fmt = "".join(
+            _to_fmt(
+                field_descr.type,
+                size=field_descr.size,
+                bitorder=bitorder,
+                byteorder=byteorder,
+                signed=field_descr.signed,
+                repeat=field_descr.repeat,
+            )
             for field_descr in field_descriptors(descriptor, pad=True)
         )
         fmt = fmt + byteorder  # byte order
@@ -165,8 +183,10 @@ class Codec(bpack.codecs.BaseStructCodec):
         converters_map = {
             field_descr.type: from_enum
             for field_descr in field_descriptors(descriptor)
-            if (bpack.utils.is_enum_type(field_descr.type) and
-                not issubclass(field_descr.type, int))
+            if (
+                bpack.utils.is_enum_type(field_descr.type)
+                and not issubclass(field_descr.type, int)
+            )
         }
         return converters_map
 
@@ -176,27 +196,29 @@ Decoder = Encoder = Codec
 decoder = encoder = codec
 
 
-@functools.lru_cache()
-def _get_sequence_codec(nsamples: int, bits_per_sample, signed=False,
-                        byteorder: str = '') -> BitStruct:
+@functools.lru_cache()  # @COPMPATIBILITY with Python 3.7
+def _get_sequence_codec(
+    nsamples: int, bits_per_sample, signed=False, byteorder: str = ""
+) -> BitStruct:
     nbits = nsamples * bits_per_sample
     outsize = math.ceil(nbits / 8)
     npad = outsize * 8 - nbits
 
     if signed:
-        fmt = f's{bits_per_sample:d}' * nsamples
+        fmt = f"s{bits_per_sample:d}" * nsamples
     else:
-        fmt = f'u{bits_per_sample:d}' * nsamples
+        fmt = f"u{bits_per_sample:d}" * nsamples
 
     if npad > 0:
-        fmt += f'p{npad:d}'
+        fmt += f"p{npad:d}"
 
     fmt += byteorder
     return BitStruct(fmt)
 
 
-def packbits(values, bits_per_sample: int, signed: bool = False,
-             byteorder: str = '') -> bytes:
+def packbits(
+    values, bits_per_sample: int, signed: bool = False, byteorder: str = ""
+) -> bytes:
     """Pack integer values using the specified number of bits for each sample.
 
     Converts a sequence of values into a string of bytes in which each
@@ -221,15 +243,22 @@ def packbits(values, bits_per_sample: int, signed: bool = False,
     """
     nsamples = len(values)
     if (nsamples * bits_per_sample) % 8:
-        warnings.warn(f'packing {nsamples} with {bits_per_sample} bits per '
-                      f'sample requires padding')
-    encoder_ = _get_sequence_codec(nsamples, bits_per_sample,
-                                   signed=signed, byteorder=byteorder)
+        warnings.warn(
+            f"packing {nsamples} with {bits_per_sample} bits per "
+            f"sample requires padding"
+        )
+    encoder_ = _get_sequence_codec(
+        nsamples, bits_per_sample, signed=signed, byteorder=byteorder
+    )
     return encoder_.pack(*values)
 
 
-def unpackbits(data: bytes, bits_per_sample: int, signed: bool = False,
-               byteorder: str = ''):
+def unpackbits(
+    data: bytes,
+    bits_per_sample: int,
+    signed: bool = False,
+    byteorder: str = "",
+):
     """Unpack packed (integer) values form a string of bytes.
 
     Takes in input a string of bytes in which (integer) samples have been
@@ -248,6 +277,7 @@ def unpackbits(data: bytes, bits_per_sample: int, signed: bool = False,
     signed integers.
     """
     nsamples = len(data) * 8 // bits_per_sample
-    decoder_ = _get_sequence_codec(nsamples, bits_per_sample,
-                                   signed=signed, byteorder=byteorder)
+    decoder_ = _get_sequence_codec(
+        nsamples, bits_per_sample, signed=signed, byteorder=byteorder
+    )
     return decoder_.unpack(data)
