@@ -8,26 +8,41 @@ import warnings
 import dataclasses
 from typing import Iterable, Optional, Sequence, Type, Union
 
-import bpack.typing
 import bpack.utils
-from .utils import classdecorator
+import bpack.typing
+
 from .enums import EBaseUnits, EByteOrder, EBitOrder
+from .utils import classdecorator
 
 __all__ = [
-    'descriptor', 'is_descriptor', 'fields', 'asdict', 'astuple', 'calcsize',
-    'baseunits', 'byteorder', 'bitorder', 'field', 'Field', 'is_field',
-    'field_descriptors',
-    'BinFieldDescriptor', 'get_field_descriptor', 'set_field_descriptor',
-    'BASEUNITS_ATTR_NAME', 'BYTEORDER_ATTR_NAME', 'BITORDER_ATTR_NAME',
-    'METADATA_KEY',
+    "descriptor",
+    "is_descriptor",
+    "fields",
+    "asdict",
+    "astuple",
+    "calcsize",
+    "baseunits",
+    "byteorder",
+    "bitorder",
+    "field",
+    "Field",
+    "is_field",
+    "field_descriptors",
+    "BinFieldDescriptor",
+    "get_field_descriptor",
+    "set_field_descriptor",
+    "BASEUNITS_ATTR_NAME",
+    "BYTEORDER_ATTR_NAME",
+    "BITORDER_ATTR_NAME",
+    "METADATA_KEY",
 ]
 
 
-BASEUNITS_ATTR_NAME = '__bpack_baseunits__'
-BYTEORDER_ATTR_NAME = '__bpack_byteorder__'
-BITORDER_ATTR_NAME = '__bpack_bitorder__'
-SIZE_ATTR_NAME = '__bpack_size__'
-METADATA_KEY = '__bpack_metadata__'
+BASEUNITS_ATTR_NAME = "__bpack_baseunits__"
+BYTEORDER_ATTR_NAME = "__bpack_byteorder__"
+BITORDER_ATTR_NAME = "__bpack_bitorder__"
+SIZE_ATTR_NAME = "__bpack_size__"
+METADATA_KEY = "__bpack_metadata__"
 
 
 class DescriptorConsistencyError(ValueError):
@@ -57,28 +72,31 @@ def _resolve_type(type_):
 
 @dataclasses.dataclass
 class BinFieldDescriptor:
-    """Descriptor for bpack fields."""
+    """Descriptor for bpack fields.
 
-    type: Optional[Type] = None
-    size: Optional[int] = None          # item size
+    See also :func:`bpack.filed` for a description of the attributes.
+    """
+
+    type: Optional[Type] = None  # noqa: A003
+    size: Optional[int] = None  #: item size
     offset: Optional[int] = None
     signed: Optional[bool] = None
-    repeat: Optional[int] = None        # number of items
+    repeat: Optional[int] = None  #: number of items
     # converter: Optional[Callable] = None
 
     def _validate_type(self):
         if self.type is None:
-            raise TypeError(f'invalid type "{self.type}"')
+            raise TypeError(f"invalid type '{self.type}'")
 
     def _validate_size(self):
-        msg = f'invalid size: {self.size!r} (must be a positive integer)'
+        msg = f"invalid size: {self.size!r} (must be a positive integer)"
         if not isinstance(self.size, int):
             raise TypeError(msg)
         if self.size <= 0:
             raise ValueError(msg)
 
     def _validate_offset(self):
-        msg = f'invalid offset: {self.offset!r} (must be an integer >= 0)'
+        msg = f"invalid offset: {self.offset!r} (must be an integer >= 0)"
         if not isinstance(self.offset, int):
             raise TypeError(msg)
         if self.offset < 0:
@@ -87,11 +105,12 @@ class BinFieldDescriptor:
     def _validate_signed(self):
         if not isinstance(self.signed, bool):
             raise TypeError(
-                f'invalid "signed" parameter: {self.signed!r} '
-                f'(must be a bool or None)')
+                f"invalid 'signed' parameter: {self.signed!r} "
+                f"(must be a bool or None)"
+            )
 
     def _validate_repeat(self):
-        msg = f'invalid repeat: {self.repeat!r} (must be a positive)'
+        msg = f"invalid repeat: {self.repeat!r} (must be a positive)"
         if not isinstance(self.repeat, int):
             raise TypeError(msg)
         if self.repeat < 1:
@@ -126,28 +145,34 @@ class BinFieldDescriptor:
             self._validate_signed()
             if not self.is_int_type():
                 warnings.warn(
-                    f'the "signed" parameter will be ignored for non-integer '
-                    f'type: "{self.type}"')
+                    f"the 'signed' parameter will be ignored for non-integer "
+                    f"type: '{self.type}'"
+                )
         if self.repeat is not None:
             self._validate_repeat()
             if not self.is_sequence_type() and self.repeat is not None:
                 raise TypeError(
-                    f'repeat parameter specified for non-sequence type: '
-                    f'{self.type}')
+                    f"repeat parameter specified for non-sequence type: "
+                    f"{self.type}"
+                )
         if bpack.utils.is_enum_type(self.type):
             self._validate_enum_type()
         elif self.is_sequence_type() and self.repeat is None:
             raise TypeError(
-                f'no "repeat" parameter specified for sequence type '
-                f'{self.type}')
+                f"no 'repeat' parameter specified for sequence type "
+                f"{self.type}"
+            )
 
     def is_int_type(self) -> bool:
+        """Return True if the field is an integer or a sub-type of integer."""
         return bpack.utils.is_int_type(self.type)
 
     def is_sequence_type(self) -> bool:
+        """Return True if the field is a sequence."""
         return bpack.utils.is_sequence_type(self.type, error=True)
 
     def is_enum_type(self) -> bool:
+        """Return True if the field is an enum."""
         return bpack.utils.is_enum_type(self.type)
 
     @property
@@ -163,8 +188,9 @@ class BinFieldDescriptor:
         return True
 
     def update_from_type(self, type_: Type):
+        """Update the field descriptor according to the specified type."""
         if self.type is not None:
-            raise TypeError('the type attribute is already set')
+            raise TypeError("the type attribute is already set")
         if bpack.typing.is_annotated(type_):
             _, params = bpack.typing.get_args(type_)
             valid = True
@@ -174,8 +200,9 @@ class BinFieldDescriptor:
                 valid = False
             if not valid:
                 raise DescriptorConsistencyError(
-                    f'type string "{params}" is incompatible with the '
-                    f'field descriptor {self}')
+                    f"type string '{params}' is incompatible with the "
+                    f"field descriptor {self}"
+                )
 
             self.type = params.type
             if self.signed is None:
@@ -193,26 +220,57 @@ class BinFieldDescriptor:
 Field = dataclasses.Field
 
 
-def field(*, size: Optional[int] = None, offset: Optional[int] = None,
-          signed: Optional[bool] = None, repeat: Optional[int] = None,
-          metadata=None, **kwargs) -> Field:
+def field(
+    *,
+    size: Optional[int] = None,
+    offset: Optional[int] = None,
+    signed: Optional[bool] = None,
+    repeat: Optional[int] = None,
+    metadata=None,
+    **kwargs,
+) -> Field:
     """Initialize a field descriptor.
 
     Returned object is a :class:`Field` instance with metadata properly
     initialized to describe the field of a binary record.
+
+    :param size: int
+        size of the field in :class:`EBaseUnits`
+    :param offset: int
+        offset of the field w.r.t. the beginning of the record
+        (expressed in :class:`EBaseUnits`)
+    :param signed: bool
+        True if an `int` field is signed, False otherwise.
+        This parameter must not be specified for non `int` fields.
+    :param repeat: int
+        length of the sequence for `sequence` fields, i.e. fields
+        consisting in multiple items having the same data type.
+        This parameter must not be specified if the data type is not a
+        sequence type (e.g. `List`).
+    :param metadata:
+        additional metadata to be attached the the field descriptor.
+    :param kwargs:
+        additional keyword arguments for the :func:`dataclasses.field`
+        function.
+
     """
-    field_descr = BinFieldDescriptor(size=size, offset=offset, signed=signed,
-                                     repeat=repeat)
+    field_descr = BinFieldDescriptor(
+        size=size, offset=offset, signed=signed, repeat=repeat
+    )
     metadata = metadata.copy() if metadata is not None else {}
     metadata[METADATA_KEY] = types.MappingProxyType(
-        dataclasses.asdict(field_descr))
+        dataclasses.asdict(field_descr)
+    )
     return dataclasses.field(metadata=metadata, **kwargs)
 
 
 def is_field(obj) -> bool:
     """Return true if an ``obj`` can be considered is a field descriptor."""
-    return (isinstance(obj, Field) and obj.metadata and
-            METADATA_KEY in obj.metadata)
+    return (
+        isinstance(obj, Field)
+        and obj.metadata
+        and METADATA_KEY in obj.metadata
+    )
 
 
 def _update_field_metadata(field_, **kwargs):
@@ -222,11 +280,12 @@ def _update_field_metadata(field_, **kwargs):
     return field_
 
 
-def get_field_descriptor(field: Field,                                  # noqa
-                         validate: bool = True) -> BinFieldDescriptor:
+def get_field_descriptor(
+    field: Field, validate: bool = True
+) -> BinFieldDescriptor:
     """Return the field descriptor attached to a :class:`Field`."""
     if not is_field(field):
-        raise NotFieldDescriptorError(f'not a field descriptor: {field}')
+        raise NotFieldDescriptorError(f"not a field descriptor: {field}")
     field_descr = BinFieldDescriptor(**field.metadata[METADATA_KEY])
     field_descr.update_from_type(field.type)
     if validate:
@@ -234,24 +293,27 @@ def get_field_descriptor(field: Field,                                  # noqa
     return field_descr
 
 
-def set_field_descriptor(field: Field, descriptor: BinFieldDescriptor,  # noqa
-                         validate: bool = True) -> Field:
+def set_field_descriptor(
+    field: Field, descriptor: BinFieldDescriptor, validate: bool = True
+) -> Field:
     """Set the field metadata according to the specified descriptor."""
     if validate:
         descriptor.validate()
     field_descr_metadata = {
-        k: v for k, v in dataclasses.asdict(descriptor).items()
+        k: v
+        for k, v in dataclasses.asdict(descriptor).items()
         if v is not None
     }
-    type_ = field_descr_metadata.pop('type', None)
+    type_ = field_descr_metadata.pop("type", None)
     if bpack.typing.is_annotated(field.type):
         field_type, _ = bpack.typing.get_args(field.type)
     else:
         field_type = field.type
     if type_ != _resolve_type(field_type):
         raise TypeError(
-            f'type mismatch between BinFieldDescriptor.type ({type_!r}) and '
-            f'filed.type ({field.type!r})')
+            f"type mismatch between BinFieldDescriptor.type ({type_!r}) and "
+            f"filed.type ({field.type!r})"
+        )
     new_metadata = {
         METADATA_KEY: types.MappingProxyType(field_descr_metadata),
     }
@@ -273,8 +335,7 @@ _DEFAULT_SIZE_MAP = {
 }
 
 
-def _get_default_size(type_,
-                      baseunits: EBaseUnits) -> Union[int, None]:       # noqa
+def _get_default_size(type_, baseunits: EBaseUnits) -> Union[int, None]:
     if is_descriptor(type_):
         return calcsize(type_, baseunits)
 
@@ -304,12 +365,13 @@ def _get_default_size(type_,
     #     else:
     #         return None
 
-    return _DEFAULT_SIZE_MAP[baseunits].get(etype)                      # noqa
+    return _DEFAULT_SIZE_MAP[baseunits].get(etype)
 
 
-def _get_effective_byteorder(byteorder: EByteOrder,                     # noqa
-                             baseunits: EBaseUnits) -> EByteOrder:      # noqa
-    byteorder = EByteOrder(byteorder)                                   # noqa
+def _get_effective_byteorder(
+    byteorder: EByteOrder, baseunits: EBaseUnits
+) -> EByteOrder:
+    byteorder = EByteOrder(byteorder)
     effective_byteorder = byteorder
     if baseunits is EBaseUnits.BYTES:
         if byteorder in {EByteOrder.NATIVE, EByteOrder.DEFAULT}:
@@ -323,11 +385,15 @@ def _get_effective_byteorder(byteorder: EByteOrder,                     # noqa
 
 
 @classdecorator
-def descriptor(cls, *, size: Optional[int] = None,
-               byteorder: Union[str, EByteOrder] = EByteOrder.DEFAULT,  # noqa
-               bitorder: Optional[Union[str, EBitOrder]] = None,        # noqa
-               baseunits: EBaseUnits = EBaseUnits.BYTES,                # noqa
-               **kwargs):
+def descriptor(
+    cls,
+    *,
+    size: Optional[int] = None,
+    byteorder: Union[str, EByteOrder] = EByteOrder.DEFAULT,
+    bitorder: Optional[Union[str, EBitOrder]] = None,
+    baseunits: EBaseUnits = EBaseUnits.BYTES,
+    **kwargs,
+):
     """Class decorator to define descriptors for binary records.
 
     It converts a dataclass into a descriptor object for binary records.
@@ -357,12 +423,14 @@ def descriptor(cls, *, size: Optional[int] = None,
     It is also possible to specify as additional keyword arguments all the
     parameters accepted by :func:`dataclasses.dataclass`.
     """
-    baseunits = EBaseUnits(baseunits)                                   # noqa
-    byteorder = EByteOrder(byteorder)                                   # noqa
+    baseunits = EBaseUnits(baseunits)
+    byteorder = EByteOrder(byteorder)
 
     if dataclasses.is_dataclass(cls):
-        warnings.warn('the explicit use of dataclasses is deprecated',
-                      category=DeprecationWarning)
+        warnings.warn(
+            "the explicit use of dataclasses is deprecated",
+            category=DeprecationWarning,
+        )
     else:
         cls = dataclasses.dataclass(cls, **kwargs)
 
@@ -383,13 +451,15 @@ def descriptor(cls, *, size: Optional[int] = None,
             # check byteorder
             _, params = bpack.typing.get_args(field_.type)
             if params.byteorder:
-                effective_byteorder = _get_effective_byteorder(byteorder,
-                                                               baseunits)
+                effective_byteorder = _get_effective_byteorder(
+                    byteorder, baseunits
+                )
                 if params.byteorder != effective_byteorder:
                     raise DescriptorConsistencyError(
-                        f'the byteorder of field {field_.name} '
-                        f'("{params.byteorder}" is not consistent with the '
-                        f'descriptor byteorder ({byteorder}) )')
+                        f"the byteorder of field {field_.name} "
+                        f"('{params.byteorder}' is not consistent with the "
+                        f"descriptor byteorder ({byteorder}) )"
+                    )
 
         try:
             field_descr = get_field_descriptor(field_, validate=False)
@@ -404,12 +474,15 @@ def descriptor(cls, *, size: Optional[int] = None,
         if field_descr.size is None:
             raise TypeError(f'size not specified for field: "{field_.name}"')
 
-        if (is_descriptor(field_descr.type) and
-                calcsize(field_descr.type, baseunits) != field_descr.size):
+        if (
+            is_descriptor(field_descr.type)
+            and calcsize(field_descr.type, baseunits) != field_descr.size
+        ):
             raise DescriptorConsistencyError(
-                f'mismatch between field.size ({field_descr.size}) and size '
-                f'of field.type ({calcsize(field_descr.type, baseunits)}) '
-                f'in field "{field_.name}"')
+                f"mismatch between field.size ({field_descr.size}) and size "
+                f"of field.type ({calcsize(field_descr.type, baseunits)}) "
+                f"in field '{field_.name}'"
+            )
 
         auto_offset = prev_field_descr.offset + prev_field_descr.total_size
 
@@ -417,7 +490,8 @@ def descriptor(cls, *, size: Optional[int] = None,
             field_descr.offset = auto_offset
         elif field_descr.offset < auto_offset:
             raise DescriptorConsistencyError(
-                f'invalid offset for filed n. {idx}: {field_}')
+                f"invalid offset for filed n. {idx}: {field_}"
+            )
 
         set_field_descriptor(field_, field_descr)
         prev_field_descr = field_descr
@@ -430,27 +504,32 @@ def descriptor(cls, *, size: Optional[int] = None,
     if size is None:
         size = auto_size
     elif int(size) != size:
-        raise TypeError(f'invalid size: {size!r}')
+        raise TypeError(f"invalid size: {size!r}")
     elif size < auto_size:
         raise DescriptorConsistencyError(
-            f'the specified size ({size}) is smaller than total size of '
-            f'fields ({auto_size})')
+            f"the specified size ({size}) is smaller than total size of "
+            f"fields ({auto_size})"
+        )
 
     if baseunits is EBaseUnits.BITS:
         if size % 8 != 0:
-            warnings.warn('bit struct not aligned to bytes')
+            warnings.warn("bit struct not aligned to bytes")
 
     if baseunits is not EBaseUnits.BITS and bitorder is not None:
         raise ValueError(
-            'it is not possible to specify the "bitorder" '
-            'if "baseunits" is not "BITS"')
+            "it is not possible to specify the 'bitorder' "
+            "if 'baseunits' is not 'BITS'"
+        )
     elif baseunits is EBaseUnits.BITS and bitorder is None:
-        bitorder = EBitOrder.DEFAULT                                    # noqa
+        bitorder = EBitOrder.DEFAULT
 
     setattr(cls, BASEUNITS_ATTR_NAME, baseunits)
     setattr(cls, BYTEORDER_ATTR_NAME, byteorder)
-    setattr(cls, BITORDER_ATTR_NAME,
-            EBitOrder(bitorder) if bitorder is not None else None)
+    setattr(
+        cls,
+        BITORDER_ATTR_NAME,
+        EBitOrder(bitorder) if bitorder is not None else None,
+    )
     setattr(cls, SIZE_ATTR_NAME, size)
 
     return cls
@@ -458,7 +537,7 @@ def descriptor(cls, *, size: Optional[int] = None,
 
 def fields(obj) -> Sequence[Field]:
     """Return a tuple describing the fields of this descriptor."""
-    return dataclasses.fields(obj)                                      # noqa
+    return dataclasses.fields(obj)
 
 
 def is_descriptor(obj) -> bool:
@@ -488,7 +567,7 @@ def asdict(obj, *, dict_factory=dict) -> dict:
 
 
 def astuple(obj, *, tuple_factory=tuple) -> Sequence:
-    """Return the fields of a dataclass instance as a new tuple of field values.
+    """Return the fields of a dataclass instance as new tuple of field values.
 
     If given, 'tuple_factory' will be used instead of built-in tuple.
     The function applies recursively to field values that are
@@ -505,7 +584,7 @@ def calcsize(obj, units: Optional[EBaseUnits] = None) -> int:
     *size* is expressed in the same *base units* of the descriptor.
     """
     if not is_descriptor(obj):
-        raise TypeError(f'{obj!r} is not a descriptor')
+        raise TypeError(f"{obj!r} is not a descriptor")
 
     size = getattr(obj, SIZE_ATTR_NAME)
 
@@ -547,8 +626,9 @@ def bitorder(obj) -> Union[EBitOrder, None]:
         raise TypeError(f'"{obj}" is not a descriptor')
 
 
-def field_descriptors(descriptor,                                       # noqa
-                      pad: bool = False) -> Iterable[BinFieldDescriptor]:
+def field_descriptors(
+    descriptor, pad: bool = False
+) -> Iterable[BinFieldDescriptor]:
     """Return the list of field descriptors for the input record descriptor.
 
     Items are instances of the :class:`BinFieldDescriptor` class describing
@@ -565,8 +645,9 @@ def field_descriptors(descriptor,                                       # noqa
             assert field_descr.offset >= offset
             if field_descr.offset > offset:
                 # padding
-                yield BinFieldDescriptor(size=field_descr.offset - offset,
-                                         offset=offset)
+                yield BinFieldDescriptor(
+                    size=field_descr.offset - offset, offset=offset
+                )
                 # offset = field_.offset
             yield field_descr
             offset = field_descr.offset + field_descr.total_size
