@@ -13,7 +13,7 @@ from bpack.descriptors import BinFieldDescriptor, METADATA_KEY
 
 def test_is_descriptor():
     assert not bpack.is_descriptor(1)
-    assert not bpack.is_descriptor('x')
+    assert not bpack.is_descriptor("x")
 
     class C:
         pass
@@ -31,7 +31,7 @@ def test_is_descriptor():
     @bpack.descriptor
     class Record:
         field_1: int = bpack.field(size=4, default=0)
-        field_2: float = bpack.field(size=8, default=1/3)
+        field_2: float = bpack.field(size=8, default=1 / 3)
 
     assert bpack.is_descriptor(Record)
     assert bpack.is_descriptor(Record())
@@ -39,7 +39,7 @@ def test_is_descriptor():
     class Record:
         field_1: int = 0
 
-    setattr(Record, bpack.descriptors.BASEUNITS_ATTR_NAME, 'dummy')
+    setattr(Record, bpack.descriptors.BASEUNITS_ATTR_NAME, "dummy")
 
     assert not bpack.is_descriptor(Record)
     assert not bpack.is_descriptor(Record())
@@ -47,7 +47,7 @@ def test_is_descriptor():
     class Record:
         pass
 
-    setattr(Record, bpack.descriptors.BASEUNITS_ATTR_NAME, 'dummy')
+    setattr(Record, bpack.descriptors.BASEUNITS_ATTR_NAME, "dummy")
 
     assert not bpack.is_descriptor(Record)
     assert not bpack.is_descriptor(Record())
@@ -55,7 +55,7 @@ def test_is_descriptor():
     class Record:
         pass
 
-    setattr(Record, bpack.descriptors.BASEUNITS_ATTR_NAME, 'dummy')
+    setattr(Record, bpack.descriptors.BASEUNITS_ATTR_NAME, "dummy")
 
     assert not bpack.is_descriptor(Record)
     assert not bpack.is_descriptor(Record())
@@ -65,7 +65,7 @@ def test_is_field():
     @bpack.descriptor
     class Record:
         field_1: int = bpack.field(size=4, default=0)
-        field_2: float = bpack.field(size=8, default=1/3)
+        field_2: float = bpack.field(size=8, default=1 / 3)
 
     for field_ in bpack.fields(Record):
         assert bpack.is_field(field_)
@@ -89,13 +89,13 @@ def test_calcsize():
     assert bpack.calcsize(Record()) == 16
     assert bpack.calcsize(Record, EBaseUnits.BYTES) == 16
     assert bpack.calcsize(Record, EBaseUnits.BITS) == 16 * 8
-    assert bpack.calcsize(Record, 'bytes') == 16                    # noqa
-    assert bpack.calcsize(Record, 'bits') == 16 * 8                 # noqa
+    assert bpack.calcsize(Record, "bytes") == 16
+    assert bpack.calcsize(Record, "bits") == 16 * 8
 
     @bpack.descriptor(baseunits=EBaseUnits.BITS)
     class Record:
         field_1: int = bpack.field(size=4, default=0)
-        field_2: float = bpack.field(size=16, default=1/3)
+        field_2: float = bpack.field(size=16, default=1 / 3)
         field_3: int = bpack.field(size=4, default=3)
         field_4: List[int] = bpack.field(size=4, default=0, repeat=2)
 
@@ -129,7 +129,7 @@ def test_fields():
     @bpack.descriptor
     class Record:
         field_1: int = bpack.field(size=4, default=0)
-        field_2: float = bpack.field(size=8, default=1/3)
+        field_2: float = bpack.field(size=8, default=1 / 3)
 
     assert isinstance(bpack.fields(Record), tuple)
     assert len(bpack.fields(Record)) == 2
@@ -141,7 +141,7 @@ def test_get_baseunits():
     @bpack.descriptor
     class Record:
         field_1: int = bpack.field(size=4, default=0)
-        field_2: float = bpack.field(size=8, default=1/3)
+        field_2: float = bpack.field(size=8, default=1 / 3)
 
     assert bpack.baseunits(Record) == EBaseUnits.BYTES
     assert bpack.baseunits(Record()) == EBaseUnits.BYTES
@@ -149,7 +149,7 @@ def test_get_baseunits():
     @bpack.descriptor(baseunits=EBaseUnits.BYTES)
     class Record:
         field_1: int = bpack.field(size=4, default=0)
-        field_2: float = bpack.field(size=8, default=1/3)
+        field_2: float = bpack.field(size=8, default=1 / 3)
 
     assert bpack.baseunits(Record) == EBaseUnits.BYTES
     assert bpack.baseunits(Record()) == EBaseUnits.BYTES
@@ -157,7 +157,7 @@ def test_get_baseunits():
     @bpack.descriptor(baseunits=EBaseUnits.BITS, size=16)
     class Record:
         field_1: int = bpack.field(size=4, default=0)
-        field_2: float = bpack.field(size=8, default=1/3)
+        field_2: float = bpack.field(size=8, default=1 / 3)
 
     assert bpack.baseunits(Record) == EBaseUnits.BITS
     assert bpack.baseunits(Record()) == EBaseUnits.BITS
@@ -170,14 +170,15 @@ def test_get_baseunits():
         bpack.baseunits(Record)
 
 
-@pytest.mark.parametrize('byteorder',
-                         [EByteOrder.LE, EByteOrder.BE, EByteOrder.NATIVE,
-                          EByteOrder.DEFAULT])
+@pytest.mark.parametrize(
+    "byteorder",
+    [EByteOrder.LE, EByteOrder.BE, EByteOrder.NATIVE, EByteOrder.DEFAULT],
+)
 def test_byteorder_explicit(byteorder):
     @bpack.descriptor(byteorder=byteorder)
     class Record:
         field_1: int = bpack.field(size=4, default=0)
-        field_2: float = bpack.field(size=8, default=1/3)
+        field_2: float = bpack.field(size=8, default=1 / 3)
 
     assert bpack.byteorder(Record) is byteorder
     assert bpack.byteorder(Record()) is byteorder
@@ -187,7 +188,7 @@ def test_byteorder():
     @bpack.descriptor
     class Record:
         field_1: int = bpack.field(size=4, default=0)
-        field_2: float = bpack.field(size=8, default=1/3)
+        field_2: float = bpack.field(size=8, default=1 / 3)
 
     assert bpack.byteorder(Record) is EByteOrder.DEFAULT
     assert bpack.byteorder(Record()) is EByteOrder.DEFAULT
@@ -206,13 +207,14 @@ def test_byteorder():
         bpack.byteorder(Dummy)
 
 
-@pytest.mark.parametrize('bitorder',
-                         [EBitOrder.MSB, EBitOrder.LSB, EBitOrder.DEFAULT])
+@pytest.mark.parametrize(
+    "bitorder", [EBitOrder.MSB, EBitOrder.LSB, EBitOrder.DEFAULT]
+)
 def test_bitorder(bitorder):
     @bpack.descriptor(bitorder=bitorder, baseunits=EBaseUnits.BITS)
     class Record:
         field_1: int = bpack.field(size=4, default=0)
-        field_2: float = bpack.field(size=8, default=1/3)
+        field_2: float = bpack.field(size=8, default=1 / 3)
         field_3: int = bpack.field(size=4, default=0)
 
     assert bpack.bitorder(Record) is bitorder
@@ -238,20 +240,24 @@ def test_field_descriptors_iter():
     @bpack.descriptor
     class Record:
         field_1: int = bpack.field(size=4, default=0)
-        field_2: float = bpack.field(size=8, default=1/3)
+        field_2: float = bpack.field(size=8, default=1 / 3)
 
     field_descriptors = bpack.descriptors.field_descriptors(Record)
     assert isinstance(field_descriptors, collections.abc.Iterable)
     field_descriptors = list(field_descriptors)
-    assert all(isinstance(field_descr, BinFieldDescriptor)
-               for field_descr in field_descriptors)
+    assert all(
+        isinstance(field_descr, BinFieldDescriptor)
+        for field_descr in field_descriptors
+    )
     assert len(field_descriptors) == 2
 
     field_descriptors = bpack.descriptors.field_descriptors(Record())
     assert isinstance(field_descriptors, collections.abc.Iterable)
     field_descriptors = list(field_descriptors)
-    assert all(isinstance(field_descr, BinFieldDescriptor)
-               for field_descr in field_descriptors)
+    assert all(
+        isinstance(field_descr, BinFieldDescriptor)
+        for field_descr in field_descriptors
+    )
     assert len(field_descriptors) == 2
 
 
@@ -259,15 +265,17 @@ def test_field_descriptors_iter_with_pad():
     @bpack.descriptor(size=24)
     class Record:
         field_1: int = bpack.field(size=4, default=0)
-        field_2: float = bpack.field(size=8, default=1/3, offset=8)
+        field_2: float = bpack.field(size=8, default=1 / 3, offset=8)
 
     types_ = [int, None, float, None]
 
     field_descriptors = bpack.descriptors.field_descriptors(Record, pad=True)
     assert isinstance(field_descriptors, collections.abc.Iterable)
     field_descriptors = list(field_descriptors)
-    assert all(isinstance(field_descr, BinFieldDescriptor)
-               for field_descr in field_descriptors)
+    assert all(
+        isinstance(field_descr, BinFieldDescriptor)
+        for field_descr in field_descriptors
+    )
     assert len(field_descriptors) == 4
     assert [descr.type for descr in field_descriptors] == types_
     assert sum(descr.size for descr in field_descriptors) == 24
@@ -276,8 +284,10 @@ def test_field_descriptors_iter_with_pad():
     field_descriptors = bpack.descriptors.field_descriptors(Record(), pad=True)
     assert isinstance(field_descriptors, collections.abc.Iterable)
     field_descriptors = list(field_descriptors)
-    assert all(isinstance(field_descr, BinFieldDescriptor)
-               for field_descr in field_descriptors)
+    assert all(
+        isinstance(field_descr, BinFieldDescriptor)
+        for field_descr in field_descriptors
+    )
     assert len(field_descriptors) == 4
     assert [descr.type for descr in field_descriptors] == types_
     assert sum(descr.size for descr in field_descriptors) == 24
@@ -310,8 +320,9 @@ def test_get_field_descriptor_02():
         field_2: float = bpack.field(size=4, offset=3, default=0.1)
 
     data = [(int, 1, 2, True), (float, 4, 3, None)]
-    for field, (type_, size, offset, signed) in zip(bpack.fields(Record),
-                                                    data):
+    for field, (type_, size, offset, signed) in zip(
+        bpack.fields(Record), data
+    ):
         descr = bpack.descriptors.get_field_descriptor(field)
         assert descr.type is type_
         assert descr.size == size
@@ -319,8 +330,9 @@ def test_get_field_descriptor_02():
         assert descr.signed is signed
 
     record = Record()
-    for field, (type_, size, offset, signed) in zip(bpack.fields(record),
-                                                    data):
+    for field, (type_, size, offset, signed) in zip(
+        bpack.fields(record), data
+    ):
         descr = bpack.descriptors.get_field_descriptor(field)
         assert descr.type is type_
         assert descr.size == size
@@ -345,7 +357,7 @@ def test_set_field_descriptor_type_mismatch():
     field.type = int
 
     descr = bpack.descriptors.BinFieldDescriptor(type=float, size=1)
-    with pytest.raises(TypeError, match='mismatch'):
+    with pytest.raises(TypeError, match="mismatch"):
         bpack.descriptors.set_field_descriptor(field, descr)
 
 
@@ -354,9 +366,9 @@ def test_set_field_descriptor_values():
     field.type = int
     assert not bpack.is_field(field)
 
-    descr = bpack.descriptors.BinFieldDescriptor(type=field.type,
-                                                 size=1, offset=2,
-                                                 signed=True)
+    descr = bpack.descriptors.BinFieldDescriptor(
+        type=field.type, size=1, offset=2, signed=True
+    )
     bpack.descriptors.set_field_descriptor(field, descr)
     assert bpack.is_field(field)
 
@@ -370,9 +382,9 @@ def test_set_field_descriptor_values():
 def test_field_descriptor_metadata():
     field = bpack.field()
     field.type = int
-    descr = bpack.descriptors.BinFieldDescriptor(type=field.type,
-                                                 size=1, offset=2,
-                                                 signed=True)
+    descr = bpack.descriptors.BinFieldDescriptor(
+        type=field.type, size=1, offset=2, signed=True
+    )
     bpack.descriptors.set_field_descriptor(field, descr)
     assert field.metadata is not None
     assert METADATA_KEY in field.metadata
@@ -381,15 +393,15 @@ def test_field_descriptor_metadata():
     assert isinstance(descr_metadata, collections.abc.Mapping)
     with pytest.raises(TypeError):
         # immutable (types.MappingProxyType)
-        descr_metadata['new_key'] = 'new_value'                         # noqa
+        descr_metadata["new_key"] = "new_value"
 
-    assert 'type' not in descr_metadata
-    assert 'size' in descr_metadata
-    assert descr_metadata['size'] == 1
-    assert 'offset' in descr_metadata
-    assert descr_metadata['offset'] == 2
-    assert 'signed' in descr_metadata
-    assert descr_metadata['signed'] is True
+    assert "type" not in descr_metadata
+    assert "size" in descr_metadata
+    assert descr_metadata["size"] == 1
+    assert "offset" in descr_metadata
+    assert descr_metadata["offset"] == 2
+    assert "signed" in descr_metadata
+    assert descr_metadata["signed"] is True
     assert len(descr_metadata) == 3
 
 
@@ -401,9 +413,9 @@ def test_field_descriptor_minimal_metadata():
     bpack.descriptors.set_field_descriptor(field, descr)
     descr_metadata = field.metadata[bpack.descriptors.METADATA_KEY]
 
-    assert 'type' not in descr_metadata
-    assert 'size' in descr_metadata
-    assert descr_metadata['size'] == 1
+    assert "type" not in descr_metadata
+    assert "size" in descr_metadata
+    assert descr_metadata["size"] == 1
     assert len(descr_metadata) == 1
 
 
@@ -414,8 +426,9 @@ def test_asdict():
         field_2: float = bpack.field(size=4, default=0.1)
 
     record = Record()
-    assert bpack.asdict(record) == dict(field_1=record.field_1,
-                                        field_2=record.field_2)
+    assert bpack.asdict(record) == dict(
+        field_1=record.field_1, field_2=record.field_2
+    )
 
 
 def test_astuple():
@@ -426,12 +439,13 @@ def test_astuple():
 
     @bpack.descriptor
     class Record:
-        field_1: str = bpack.field(size=20, default='field_3_value')
-        field_2: SubRecord = SubRecord()
+        field_1: str = bpack.field(size=20, default="field_3_value")
+        field_2: SubRecord = bpack.field(default_factory=SubRecord)
 
     record = Record()
     values = (
-        record.field_1, (record.field_2.field_2_1, record.field_2.field_2_2),
+        record.field_1,
+        (record.field_2.field_2_1, record.field_2.field_2_2),
     )
     assert bpack.astuple(record) == values
     assert type(bpack.astuple(record)) is tuple
