@@ -2,7 +2,6 @@
 
 import sys
 import enum
-
 from typing import List
 
 import pytest
@@ -23,44 +22,44 @@ class TestFieldFactory:
         assert isinstance(field_, bpack.descriptors.Field)
 
     @staticmethod
-    @pytest.mark.parametrize(argnames='size', argvalues=[1.3, 'x'])
+    @pytest.mark.parametrize(argnames="size", argvalues=[1.3, "x"])
     def test_invalid_size_type(size):
         with pytest.raises(TypeError):
-            bpack.field(size=size, default=1/3)
+            bpack.field(size=size, default=1 / 3)
 
     @staticmethod
-    @pytest.mark.parametrize(argnames='size', argvalues=[0, -8])
+    @pytest.mark.parametrize(argnames="size", argvalues=[0, -8])
     def test_invalid_size(size):
         with pytest.raises(ValueError):
-            bpack.field(size=size, default=1/3)
+            bpack.field(size=size, default=1 / 3)
 
     @staticmethod
-    @pytest.mark.parametrize(argnames='offset', argvalues=[1.3, 'x'])
+    @pytest.mark.parametrize(argnames="offset", argvalues=[1.3, "x"])
     def test_invalid_offset_type(offset):
         with pytest.raises(TypeError):
-            bpack.field(size=8, default=1/3, offset=offset)
+            bpack.field(size=8, default=1 / 3, offset=offset)
 
     @staticmethod
     def test_invalid_offset():
         with pytest.raises(ValueError):
-            bpack.field(size=8, default=1/3, offset=-8)
+            bpack.field(size=8, default=1 / 3, offset=-8)
 
     @staticmethod
-    @pytest.mark.parametrize('value', [-8, 'a'])
+    @pytest.mark.parametrize("value", [-8, "a"])
     def test_invalid_signed_type(value):
         with pytest.raises(TypeError):
-            bpack.field(size=8, default=1, signed=value)                # noqa
+            bpack.field(size=8, default=1, signed=value)
 
     @staticmethod
-    @pytest.mark.parametrize(argnames='repeat', argvalues=[1.3, 'x'])
+    @pytest.mark.parametrize(argnames="repeat", argvalues=[1.3, "x"])
     def test_invalid_repeat_type(repeat):
         with pytest.raises(TypeError):
-            bpack.field(size=8, default=1/3, repeat=repeat)
+            bpack.field(size=8, default=1 / 3, repeat=repeat)
 
     @staticmethod
     def test_invalid_repeat():
         with pytest.raises(ValueError):
-            bpack.field(size=8, default=1/3, repeat=0)
+            bpack.field(size=8, default=1 / 3, repeat=0)
 
     @staticmethod
     def test_metadata_key():
@@ -74,14 +73,14 @@ class TestRecordFields:
         @bpack.descriptor
         class Record:
             field_1: int = bpack.field(size=4, default=0, signed=True)
-            field_2: float = bpack.field(size=8, default=1/3)
+            field_2: float = bpack.field(size=8, default=1 / 3)
             field_3: List[int] = bpack.field(size=1, default=1, repeat=1)
 
         # name, type, size, offset, repeat
         field_data = [
-            ('field_1', int, 4, 0, True, None),
-            ('field_2', float, 8, 4, None, None),
-            ('field_3', List[int], 1, 12, None, 1),
+            ("field_1", int, 4, 0, True, None),
+            ("field_2", float, 8, 4, None, None),
+            ("field_3", List[int], 1, 12, None, 1),
         ]
 
         for field_, data in zip(bpack.fields(Record), field_data):
@@ -99,16 +98,17 @@ class TestRecordFields:
     def test_field_properties_02():
         @bpack.descriptor
         class Record:
-            field_1: int = bpack.field(size=4, offset=1, default=0,
-                                       signed=False)
-            field_2: float = bpack.field(size=8, default=1/3)
+            field_1: int = bpack.field(
+                size=4, offset=1, default=0, signed=False
+            )
+            field_2: float = bpack.field(size=8, default=1 / 3)
             field_3: List[int] = bpack.field(size=1, default=1, repeat=1)
 
         # name, type, size, offset, repeat
         field_data = [
-            ('field_1', int, 4, 1, False, None),
-            ('field_2', float, 8, 5, None, None),
-            ('field_3', List[int], 1, 13, None, 1),
+            ("field_1", int, 4, 1, False, None),
+            ("field_2", float, 8, 5, None, None),
+            ("field_3", List[int], 1, 13, None, 1),
         ]
 
         for field_, data in zip(bpack.fields(Record), field_data):
@@ -127,12 +127,12 @@ class TestRecordFields:
         @bpack.descriptor
         class Record:
             field_1: int = bpack.field(size=4, offset=1, default=0)
-            field_2: float = bpack.field(size=8, offset=6, default=1/3)
+            field_2: float = bpack.field(size=8, offset=6, default=1 / 3)
 
         # name, type, size, offset, repeat
         field_data = [
-            ('field_1', int, 4, 1, None, None),
-            ('field_2', float, 8, 6, None, None),
+            ("field_1", int, 4, 1, None, None),
+            ("field_2", float, 8, 6, None, None),
         ]
 
         for field_, data in zip(bpack.fields(Record), field_data):
@@ -149,18 +149,19 @@ class TestRecordFields:
     @staticmethod
     def test_finvalid_field_type():
         with pytest.raises(TypeError):
+
             @bpack.descriptor
-            class Record:                                       # noqa
-                field_1: 'invalid' = bpack.field(size=4)        # noqa: F821
+            class Record:
+                field_1: "invalid" = bpack.field(size=4)  # noqa: F821
 
 
 class TestEnumFields:
     @staticmethod
     def test_enum():
         class EEnumType(enum.Enum):
-            A = 'a'
-            B = 'b'
-            C = 'c'
+            A = "a"
+            B = "b"
+            C = "c"
 
         @bpack.descriptor
         class Record:
@@ -168,7 +169,7 @@ class TestEnumFields:
             field_2: EEnumType = bpack.field(size=1, default=EEnumType.A)
 
         field_2 = bpack.fields(Record)[1]
-        assert field_2.name == 'field_2'
+        assert field_2.name == "field_2"
         assert field_2.type is EEnumType
         assert field_2.default is EEnumType.A
         assert isinstance(Record().field_2, EEnumType)
@@ -183,11 +184,12 @@ class TestEnumFields:
         @bpack.descriptor
         class Record:
             field_1: int = bpack.field(size=4, default=0)
-            field_2: EEnumType = bpack.field(size=1, signed=True,
-                                             default=EEnumType.A)
+            field_2: EEnumType = bpack.field(
+                size=1, signed=True, default=EEnumType.A
+            )
 
         field_2 = bpack.fields(Record)[1]
-        assert field_2.name == 'field_2'
+        assert field_2.name == "field_2"
         assert field_2.type is EEnumType
         assert field_2.default is EEnumType.A
         assert isinstance(Record().field_2, EEnumType)
@@ -205,7 +207,7 @@ class TestEnumFields:
             field_2: EEnumType = bpack.field(size=1, default=EEnumType.A)
 
         field_2 = bpack.fields(Record)[1]
-        assert field_2.name == 'field_2'
+        assert field_2.name == "field_2"
         assert field_2.type is EEnumType
         assert field_2.default is EEnumType.A
         assert isinstance(Record().field_2, EEnumType)
@@ -214,28 +216,31 @@ class TestEnumFields:
     def test_invalid_enum():
         class EEnumType(enum.Enum):
             A = 1
-            B = 'b'
+            B = "b"
             C = 4
 
         with pytest.raises(TypeError):
+
             @bpack.descriptor
-            class Record:                                               # noqa
+            class Record:
                 field_1: int = bpack.field(size=4, default=0)
                 field_2: EEnumType = bpack.field(size=1, default=EEnumType.A)
 
     @staticmethod
     def test_invalid_signed_qualifier():
         class EEnumType(enum.Enum):
-            A = 'a'
-            B = 'b'
-            C = 'c'
+            A = "a"
+            B = "b"
+            C = "c"
 
         with pytest.warns(UserWarning):
+
             @bpack.descriptor
-            class Record:                                               # noqa
+            class Record:
                 field_1: int = bpack.field(size=4, default=0)
-                field_2: EEnumType = bpack.field(size=1, signed=True,
-                                                 default=EEnumType.A)
+                field_2: EEnumType = bpack.field(
+                    size=1, signed=True, default=EEnumType.A
+                )
 
 
 class TestFieldDescriptor:
@@ -261,9 +266,9 @@ class TestFieldDescriptor:
 
     @staticmethod
     def test_init_kw():
-        descr = bpack.descriptors.BinFieldDescriptor(type=int, size=1,
-                                                     offset=2, signed=True,
-                                                     repeat=1)
+        descr = bpack.descriptors.BinFieldDescriptor(
+            type=int, size=1, offset=2, signed=True, repeat=1
+        )
         assert descr.type is int
         assert descr.size == 1
         assert descr.offset == 2
@@ -274,17 +279,16 @@ class TestFieldDescriptor:
     @staticmethod
     def test_init_invalid_type():
         with pytest.raises(TypeError):
-            bpack.descriptors.BinFieldDescriptor(size=1.1)              # noqa
+            bpack.descriptors.BinFieldDescriptor(size=1.1)
 
         with pytest.raises(TypeError):
-            bpack.descriptors.BinFieldDescriptor(offset=2.1)            # noqa
+            bpack.descriptors.BinFieldDescriptor(offset=2.1)
 
         with pytest.raises(TypeError):
-            bpack.descriptors.BinFieldDescriptor(
-                signed=complex(3.1, 0))                                 # noqa
+            bpack.descriptors.BinFieldDescriptor(signed=complex(3.1, 0))
 
         with pytest.raises(TypeError):
-            bpack.descriptors.BinFieldDescriptor(repeat=1.1)            # noqa
+            bpack.descriptors.BinFieldDescriptor(repeat=1.1)
 
     @staticmethod
     def test_init_invalid_value():
@@ -316,9 +320,10 @@ class TestFieldDescriptor:
 
     @staticmethod
     def test_validation_warning():
-        descr = bpack.descriptors.BinFieldDescriptor(type=float, size=4,
-                                                     signed=True)
-        with pytest.warns(UserWarning, match='ignore'):
+        descr = bpack.descriptors.BinFieldDescriptor(
+            type=float, size=4, signed=True
+        )
+        with pytest.warns(UserWarning, match="ignore"):
             descr.validate()
 
     @staticmethod
@@ -335,8 +340,9 @@ class TestFieldDescriptor:
         with pytest.raises(TypeError):
             descr.validate()
 
-        descr = bpack.descriptors.BinFieldDescriptor(type=int, size=1,
-                                                     repeat=2)
+        descr = bpack.descriptors.BinFieldDescriptor(
+            type=int, size=1, repeat=2
+        )
         with pytest.raises(TypeError):
             descr.validate()
 
@@ -349,12 +355,16 @@ class TestFieldDescriptor:
             descr.validate()
 
     @staticmethod
-    @pytest.mark.parametrize('size, error_type',
-                             [(None, TypeError),
-                              (0, ValueError),
-                              (-1, ValueError),
-                              (1.1, TypeError)],
-                             ids=['None', 'zero', 'negative', 'float'])
+    @pytest.mark.parametrize(
+        "size, error_type",
+        [
+            (None, TypeError),
+            (0, ValueError),
+            (-1, ValueError),
+            (1.1, TypeError),
+        ],
+        ids=["None", "zero", "negative", "float"],
+    )
     def test_post_validation_error_on_size(size, error_type):
         descr = bpack.descriptors.BinFieldDescriptor(int, 1, 2)
         descr.validate()
@@ -363,10 +373,11 @@ class TestFieldDescriptor:
             descr.validate()
 
     @staticmethod
-    @pytest.mark.parametrize('offset, error_type',
-                             [(-1, ValueError),
-                              (1.1, TypeError)],
-                             ids=['negative', 'float'])
+    @pytest.mark.parametrize(
+        "offset, error_type",
+        [(-1, ValueError), (1.1, TypeError)],
+        ids=["negative", "float"],
+    )
     def test_post_validation_error_on_offset(offset, error_type):
         descr = bpack.descriptors.BinFieldDescriptor(int, 1, 2)
         descr.validate()
@@ -379,7 +390,7 @@ class TestFieldDescriptor:
         descr = bpack.descriptors.BinFieldDescriptor(int, 1, 2, signed=True)
         descr.validate()
         descr.type = float
-        with pytest.warns(UserWarning, match='ignore'):
+        with pytest.warns(UserWarning, match="ignore"):
             descr.validate()
 
     @staticmethod
@@ -390,8 +401,9 @@ class TestFieldDescriptor:
         with pytest.raises(TypeError):
             descr.validate()
 
-        descr = bpack.descriptors.BinFieldDescriptor(List[int], 1, 2,
-                                                     signed=True, repeat=2)
+        descr = bpack.descriptors.BinFieldDescriptor(
+            List[int], 1, 2, signed=True, repeat=2
+        )
         descr.validate()
         descr.repeat = 0
         with pytest.raises(ValueError):
@@ -423,7 +435,7 @@ class TestFieldDescriptor:
         assert not descr.is_enum_type()
 
         class EEnumType(enum.Enum):
-            A = 'a'
+            A = "a"
 
         descr = bpack.descriptors.BinFieldDescriptor(EEnumType, 1)
         descr.validate()
@@ -452,50 +464,51 @@ class TestFieldDescriptor:
 
 class TestAnnotatedType:
     @staticmethod
-    @pytest.mark.parametrize('byteorder', ['>', '<', '|', ''],
-                             ids=['>', '<', '|', 'None'])
+    @pytest.mark.parametrize(
+        "byteorder", [">", "<", "|", ""], ids=[">", "<", "|", "None"]
+    )
     def test_annotated_type(byteorder):
-        @bpack.descriptor(byteorder=byteorder if byteorder != '|' else '')
+        @bpack.descriptor(byteorder=byteorder if byteorder != "|" else "")
         class Record:
-            field_1: bpack.T[f'{byteorder}i4']                  # noqa: F821
-            field_2: bpack.T[f'{byteorder}u4']                  # noqa: F821
-            field_3: bpack.T[f'{byteorder}f4']                  # noqa: F821
-            field_4: bpack.T[f'{byteorder}c4']                  # noqa: F821
-            field_5: bpack.T[f'{byteorder}S4']                  # noqa: F821
+            field_1: bpack.T[f"{byteorder}i4"]  # noqa: F821
+            field_2: bpack.T[f"{byteorder}u4"]  # noqa: F821
+            field_3: bpack.T[f"{byteorder}f4"]  # noqa: F821
+            field_4: bpack.T[f"{byteorder}c4"]  # noqa: F821
+            field_5: bpack.T[f"{byteorder}S4"]  # noqa: F821
 
-        fields = dict(
-            (field.name, get_field_descriptor(field))
+        fields = {
+            field.name: get_field_descriptor(field)
             for field in bpack.fields(Record)
-        )
+        }
 
-        assert fields['field_1'].type == int
-        assert fields['field_1'].size == 4
-        assert fields['field_1'].signed is True
-        assert fields['field_1'].repeat is None
+        assert fields["field_1"].type == int
+        assert fields["field_1"].size == 4
+        assert fields["field_1"].signed is True
+        assert fields["field_1"].repeat is None
 
-        assert fields['field_2'].type == int
-        assert fields['field_2'].size == 4
-        assert fields['field_2'].signed is False
-        assert fields['field_2'].repeat is None
+        assert fields["field_2"].type == int
+        assert fields["field_2"].size == 4
+        assert fields["field_2"].signed is False
+        assert fields["field_2"].repeat is None
 
-        assert fields['field_3'].type == float
-        assert fields['field_3'].size == 4
-        assert fields['field_3'].signed is None
-        assert fields['field_3'].repeat is None
+        assert fields["field_3"].type == float
+        assert fields["field_3"].size == 4
+        assert fields["field_3"].signed is None
+        assert fields["field_3"].repeat is None
 
-        assert fields['field_4'].type == complex
-        assert fields['field_4'].size == 4
-        assert fields['field_4'].signed is None
-        assert fields['field_4'].repeat is None
+        assert fields["field_4"].type == complex
+        assert fields["field_4"].size == 4
+        assert fields["field_4"].signed is None
+        assert fields["field_4"].repeat is None
 
-        assert fields['field_5'].type == bytes
-        assert fields['field_5'].size == 4
-        assert fields['field_5'].signed is None
-        assert fields['field_5'].repeat is None
+        assert fields["field_5"].type == bytes
+        assert fields["field_5"].size == 4
+        assert fields["field_5"].signed is None
+        assert fields["field_5"].repeat is None
 
     @staticmethod
     def test_list_with_annotated_type():
-        typestr = 'i4'
+        typestr = "i4"
 
         @bpack.descriptor
         class Record:
@@ -512,39 +525,42 @@ class TestAnnotatedType:
 
     @staticmethod
     def test_byteorder_consistency():
-        typestr = '>i8'
+        typestr = ">i8"
         with pytest.raises(bpack.descriptors.DescriptorConsistencyError):
+
             @bpack.descriptor(byteorder=bpack.EByteOrder.LE)
-            class Record:                                       # noqa
+            class Record:
                 field: bpack.T[typestr]
 
-        typestr = '<i8'
+        typestr = "<i8"
         with pytest.raises(bpack.descriptors.DescriptorConsistencyError):
-            @bpack.descriptor(byteorder=bpack.EByteOrder.BE)   # noqa: F811
-            class Record:                                       # noqa
+
+            @bpack.descriptor(byteorder=bpack.EByteOrder.BE)
+            class Record:  # noqa: F811
                 field: bpack.T[typestr]
 
-        typestr = '>i8' if sys.byteorder == 'little' else '<i8'
+        typestr = ">i8" if sys.byteorder == "little" else "<i8"
         with pytest.raises(bpack.descriptors.DescriptorConsistencyError):
-            @bpack.descriptor                                   # noqa: F811
-            class Record:                                       # noqa
+
+            @bpack.descriptor
+            class Record:  # noqa: F811
                 field: bpack.T[typestr]
 
-        typestr = '<i8' if sys.byteorder == 'little' else '>i8'
+        typestr = "<i8" if sys.byteorder == "little" else ">i8"
 
-        @bpack.descriptor                                       # noqa: F811
-        class Record:                                           # noqa
+        @bpack.descriptor
+        class Record:  # noqa: F811
             field: bpack.T[typestr]
 
-        typestr = '|i8'
+        typestr = "|i8"
 
-        @bpack.descriptor(byteorder=bpack.EByteOrder.BE)       # noqa: F811
-        class Record:                                           # noqa
+        @bpack.descriptor(byteorder=bpack.EByteOrder.BE)
+        class Record:  # noqa: F811
             field: bpack.T[typestr]
 
     @staticmethod
     def test_size_consistency():
-        typestr = 'i8'
+        typestr = "i8"
 
         @bpack.descriptor
         class Record:
@@ -556,7 +572,7 @@ class TestAnnotatedType:
         assert descr.repeat is None
         assert descr.signed is True
 
-        typestr = 'u8'
+        typestr = "u8"
 
         @bpack.descriptor
         class Record:
@@ -568,7 +584,7 @@ class TestAnnotatedType:
         assert descr.repeat is None
         assert descr.signed is False
 
-        typestr = 'f8'
+        typestr = "f8"
 
         @bpack.descriptor
         class Record:
@@ -582,25 +598,29 @@ class TestAnnotatedType:
 
     @staticmethod
     def test_size_consistency_error():
-        typestr = 'i8'
+        typestr = "i8"
         with pytest.raises(bpack.descriptors.DescriptorConsistencyError):
+
             @bpack.descriptor
-            class Record:                                               # noqa
+            class Record:
                 field: bpack.T[typestr] = bpack.field(size=3)
 
     @staticmethod
     def test_signed_consistency_error():
-        typestr = 'i8'
+        typestr = "i8"
         with pytest.raises(bpack.descriptors.DescriptorConsistencyError):
+
             @bpack.descriptor
-            class Record:                                               # noqa
+            class Record:
                 field: bpack.T[typestr] = bpack.field(size=8, signed=False)
 
     @staticmethod
-    @pytest.mark.parametrize('typestr',
-                             ['invalid', '@i8', '|x8', '|i0', '|ii'])
+    @pytest.mark.parametrize(
+        "typestr", ["invalid", "@i8", "|x8", "|i0", "|ii"]
+    )
     def test_invalid_typestr(typestr):
         with pytest.raises(ValueError):
+
             @bpack.descriptor
-            class Record:                                               # noqa
+            class Record:
                 field: bpack.T[typestr] = bpack.field(size=1)
