@@ -15,7 +15,7 @@ def test_base():
     @bpack.descriptor
     class Record:
         field_1: int = bpack.field(size=4, default=0)
-        field_2: float = bpack.field(size=8, default=1/3)
+        field_2: float = bpack.field(size=8, default=1 / 3)
 
     assert dataclasses.is_dataclass(Record)
     assert len(bpack.fields(Record)) == 2
@@ -27,7 +27,7 @@ def test_frozen():
     @bpack.descriptor(frozen=True)
     class Record:
         field_1: int = bpack.field(size=4, default=0)
-        field_2: float = bpack.field(size=8, default=1/3)
+        field_2: float = bpack.field(size=8, default=1 / 3)
 
     assert dataclasses.is_dataclass(Record)
     assert len(bpack.fields(Record)) == 2
@@ -37,40 +37,42 @@ def test_frozen():
 
 def test_dataclass():
     with pytest.warns(DeprecationWarning):
+
         @bpack.descriptor
         @dataclasses.dataclass
-        class Record:                                                   # noqa
+        class Record:
             field_1: int = bpack.field(size=8, default=0)
-            field_2: float = bpack.field(size=8, default=1/3)
+            field_2: float = bpack.field(size=8, default=1 / 3)
 
 
-@pytest.mark.parametrize(argnames='baseunits',
-                         argvalues=[EBaseUnits.BYTES, EBaseUnits.BITS,
-                                    'bits', 'bytes'])
+@pytest.mark.parametrize(
+    argnames="baseunits",
+    argvalues=[EBaseUnits.BYTES, EBaseUnits.BITS, "bits", "bytes"],
+)
 def test_base_units(baseunits):
     @bpack.descriptor(baseunits=baseunits)
     class Record:
         field_1: int = bpack.field(size=8, default=0)
-        field_2: float = bpack.field(size=8, default=1/3)
+        field_2: float = bpack.field(size=8, default=1 / 3)
 
     assert bpack.baseunits(Record) is EBaseUnits(baseunits)
     assert bpack.baseunits(Record()) is EBaseUnits(baseunits)
 
 
 def test_byte_alignment_warning():
-    with pytest.warns(UserWarning,
-                      match='bit struct not aligned to bytes'):
+    with pytest.warns(UserWarning, match="bit struct not aligned to bytes"):
+
         @bpack.descriptor(baseunits=EBaseUnits.BITS)
-        class Record:                                                   # noqa
+        class Record:
             field_1: int = bpack.field(size=4, default=0)
-            field_2: float = bpack.field(size=8, default=1/3)
+            field_2: float = bpack.field(size=8, default=1 / 3)
 
 
 def test_attrs():
     @bpack.descriptor
     class Record:
         field_1: int = bpack.field(size=4, default=0)
-        field_2: float = bpack.field(size=8, default=1/3)
+        field_2: float = bpack.field(size=8, default=1 / 3)
 
     assert hasattr(Record, bpack.descriptors.BASEUNITS_ATTR_NAME)
     assert hasattr(Record, bpack.descriptors.BYTEORDER_ATTR_NAME)
@@ -78,24 +80,34 @@ def test_attrs():
     assert hasattr(Record, bpack.descriptors.SIZE_ATTR_NAME)
 
 
-@pytest.mark.parametrize(argnames='baseunits', argvalues=[None, 8, 'x'])
+@pytest.mark.parametrize(argnames="baseunits", argvalues=[None, 8, "x"])
 def test_invalid_baseunits(baseunits):
     with pytest.raises(ValueError):
+
         @bpack.descriptor(baseunits=baseunits)
-        class Record:                                                   # noqa
+        class Record:
             field_1: int = bpack.field(size=4, default=0)
-            field_2: float = bpack.field(size=8, default=1/3)
+            field_2: float = bpack.field(size=8, default=1 / 3)
 
 
-@pytest.mark.parametrize(argnames='order',
-                         argvalues=[EByteOrder.LE, EByteOrder.BE,
-                                    EByteOrder.NATIVE, EByteOrder.DEFAULT,
-                                    '<', '>', '=', ''])
+@pytest.mark.parametrize(
+    argnames="order",
+    argvalues=[
+        EByteOrder.LE,
+        EByteOrder.BE,
+        EByteOrder.NATIVE,
+        EByteOrder.DEFAULT,
+        "<",
+        ">",
+        "=",
+        "",
+    ],
+)
 def test_byteorder(order):
     @bpack.descriptor(byteorder=order)
     class Record:
         field_1: int = bpack.field(size=8, default=0)
-        field_2: float = bpack.field(size=8, default=1/3)
+        field_2: float = bpack.field(size=8, default=1 / 3)
 
     if isinstance(order, str):
         assert bpack.byteorder(Record) is EByteOrder(order)
@@ -105,22 +117,24 @@ def test_byteorder(order):
         assert bpack.byteorder(Record()) is order
 
 
-@pytest.mark.parametrize(argnames='order', argvalues=['invalid', None])
+@pytest.mark.parametrize(argnames="order", argvalues=["invalid", None])
 def test_invalid_byteorder(order):
     with pytest.raises(ValueError):
+
         @bpack.descriptor(byteorder=order)
-        class Record:                                                   # noqa
+        class Record:
             field_1: int = bpack.field(size=8, default=0)
 
 
-@pytest.mark.parametrize(argnames='order',
-                         argvalues=[EBitOrder.LSB, EBitOrder.MSB,
-                                    EBitOrder.DEFAULT, '<', '>', ''])
+@pytest.mark.parametrize(
+    argnames="order",
+    argvalues=[EBitOrder.LSB, EBitOrder.MSB, EBitOrder.DEFAULT, "<", ">", ""],
+)
 def test_bitorder(order):
     @bpack.descriptor(bitorder=order, baseunits=EBaseUnits.BITS)
     class Record:
         field_1: int = bpack.field(size=8, default=0)
-        field_2: float = bpack.field(size=8, default=1/3)
+        field_2: float = bpack.field(size=8, default=1 / 3)
 
     if isinstance(order, str):
         assert bpack.bitorder(Record) is EBitOrder(order)
@@ -142,8 +156,9 @@ def test_default_bitorder():
 
 def test_invalid_bitorder():
     with pytest.raises(ValueError):
-        @bpack.descriptor(byteorder='invalid', baseunits=EBaseUnits.BITS)
-        class Record:                                                   # noqa
+
+        @bpack.descriptor(byteorder="invalid", baseunits=EBaseUnits.BITS)
+        class Record:
             field_1: int = bpack.field(size=8, default=0)
 
 
@@ -156,74 +171,83 @@ def test_bitorder_in_byte_descriptors():
     assert bpack.byteorder(Record()) is EByteOrder.DEFAULT
 
     with pytest.raises(ValueError):
-        @bpack.descriptor(bitorder=EBitOrder.DEFAULT,
-                          baseunits=EBaseUnits.BYTES)
-        class Record:                                                   # noqa
+
+        @bpack.descriptor(
+            bitorder=EBitOrder.DEFAULT, baseunits=EBaseUnits.BYTES
+        )
+        class Record:
             field_1: int = bpack.field(size=8, default=0)
 
 
 def test_invalid_field_class():
-    with pytest.raises(TypeError, match='size not specified'):
+    with pytest.raises(TypeError, match="size not specified"):
+
         @bpack.descriptor
-        class Record:                                                   # noqa
+        class Record:
             field_1: int = 0
-            field_2: float = 1/3
+            field_2: float = 1 / 3
 
 
 def test_no_field_type():
     with pytest.raises(TypeError):
+
         @bpack.descriptor
-        class Record:                                                   # noqa
+        class Record:
             field_1 = bpack.field(size=4, default=0)
 
 
 def test_invalid_field_size_type():
     with pytest.raises(TypeError):
+
         @bpack.descriptor
-        class Record:                                                   # noqa
+        class Record:
             field_1: int = bpack.field(size=4, default=0)
-            field_2: float = bpack.field(size=None, default=1/3)
+            field_2: float = bpack.field(size=None, default=1 / 3)
 
 
 def test_inconsistent_field_offset_and_size():
     with pytest.raises(ValueError):
+
         @bpack.descriptor
-        class Record:                                                   # noqa
+        class Record:
             field_1: int = bpack.field(size=4, default=0)
-            field_2: float = bpack.field(size=8, offset=1, default=1/3)
+            field_2: float = bpack.field(size=8, offset=1, default=1 / 3)
 
 
 def test_inconsistent_field_type_and_signed():
-    with pytest.warns(UserWarning, match='ignore'):
+    with pytest.warns(UserWarning, match="ignore"):
+
         @bpack.descriptor
-        class Record:                                                   # noqa
+        class Record:
             field_1: int = bpack.field(size=4, default=0)
-            field_2: float = bpack.field(size=8, default=1/3, signed=True)
+            field_2: float = bpack.field(size=8, default=1 / 3, signed=True)
 
 
 def test_repeat():
     @bpack.descriptor
     class Record:
         field_1: List[int] = bpack.field(size=4, default=0, repeat=2)
-        field_2: float = bpack.field(size=8, default=1/3)
+        field_2: float = bpack.field(size=8, default=1 / 3)
 
     assert bpack.calcsize(Record()) == 16
 
 
 def test_no_repeat():
     with pytest.raises(TypeError):
+
         @bpack.descriptor
-        class Record:                                                   # noqa
+        class Record:
             field_1: List[int] = bpack.field(size=4, default=0)
             field_2: float = bpack.field(size=8, default=1 / 3)
 
 
 def test_inconsistent_field_type_and_repeat():
     with pytest.raises(TypeError):
+
         @bpack.descriptor
-        class Record:                                                   # noqa
+        class Record:
             field_1: int = bpack.field(size=4, default=0, repeat=2)
-            field_2: float = bpack.field(size=8, default=1/3, signed=True)
+            field_2: float = bpack.field(size=8, default=1 / 3, signed=True)
 
 
 class TestExplicitSize:
@@ -234,7 +258,7 @@ class TestExplicitSize:
         @bpack.descriptor(size=size)
         class Record:
             field_1: int = bpack.field(size=4, default=0)
-            field_2: float = bpack.field(size=8, default=1/3)
+            field_2: float = bpack.field(size=8, default=1 / 3)
 
         assert bpack.calcsize(Record) == size
         assert bpack.calcsize(Record()) == size
@@ -242,43 +266,49 @@ class TestExplicitSize:
     @staticmethod
     def test_invalid_explicit_size():
         with pytest.raises(ValueError):
+
             @bpack.descriptor(size=10)
-            class Record:                                               # noqa
+            class Record:
                 field_1: int = bpack.field(size=4, default=0)
-                field_2: float = bpack.field(size=8, default=1/3)
+                field_2: float = bpack.field(size=8, default=1 / 3)
 
     @staticmethod
     def test_inconsistent_explicit_size_and_offset():
         with pytest.raises(bpack.descriptors.DescriptorConsistencyError):
+
             @bpack.descriptor(size=16)
-            class Record:                                               # noqa
+            class Record:
                 field_1: int = bpack.field(size=4, default=0)
-                field_2: float = bpack.field(size=8, default=1/3, offset=12)
+                field_2: float = bpack.field(size=8, default=1 / 3, offset=12)
 
     @staticmethod
     def test_inconsistent_explicit_size_and_repeat():
         with pytest.raises(bpack.descriptors.DescriptorConsistencyError):
+
             @bpack.descriptor(size=12)
-            class Record:                                               # noqa
+            class Record:
                 field_1: List[int] = bpack.field(size=4, default=0, repeat=2)
-                field_2: float = bpack.field(size=8, default=1/3)
+                field_2: float = bpack.field(size=8, default=1 / 3)
 
     @staticmethod
     def test_inconsistent_explicit_size_offset_and_repeat():
         with pytest.raises(bpack.descriptors.DescriptorConsistencyError):
+
             @bpack.descriptor(size=20)
-            class Record:                                               # noqa
+            class Record:
                 field_1: int = bpack.field(size=4, default=0)
-                field_2: List[float] = bpack.field(size=8, default=1/3,
-                                                   offset=8, repeat=2)
+                field_2: List[float] = bpack.field(
+                    size=8, default=1 / 3, offset=8, repeat=2
+                )
 
     @staticmethod
     def test_invalid_explicit_size_type():
         with pytest.raises(TypeError):
+
             @bpack.descriptor(size=10.5)
-            class Record:                                               # noqa
+            class Record:
                 field_1: int = bpack.field(size=4, default=0)
-                field_2: float = bpack.field(size=8, default=1/3)
+                field_2: float = bpack.field(size=8, default=1 / 3)
 
 
 class TestSize:
@@ -290,7 +320,7 @@ class TestSize:
         @bpack.descriptor
         class Record:
             field_1: int = bpack.field(size=4, default=0)
-            field_2: float = bpack.field(size=8, offset=10, default=1/3)
+            field_2: float = bpack.field(size=8, offset=10, default=1 / 3)
 
         assert bpack.calcsize(Record) == 18
 
@@ -299,7 +329,7 @@ class TestSize:
         @bpack.descriptor
         class Record:
             field_1: int = bpack.field(size=4, offset=10, default=0)
-            field_2: float = bpack.field(size=8, default=1/3)
+            field_2: float = bpack.field(size=8, default=1 / 3)
 
         assert bpack.calcsize(Record) == 22
 
@@ -308,7 +338,7 @@ class TestSize:
         @bpack.descriptor
         class Record:
             field_1: int = bpack.field(size=4, offset=10, default=0)
-            field_2: float = bpack.field(size=8, offset=20, default=1/3)
+            field_2: float = bpack.field(size=8, offset=20, default=1 / 3)
 
         assert bpack.calcsize(Record) == 28
 
@@ -319,7 +349,7 @@ class TestSize:
         @bpack.descriptor(size=size)
         class Record:
             field_1: int = bpack.field(size=4, offset=10, default=0)
-            field_2: float = bpack.field(size=8, offset=20, default=1/3)
+            field_2: float = bpack.field(size=8, offset=20, default=1 / 3)
 
         assert bpack.calcsize(Record) == size
 
@@ -328,7 +358,7 @@ class TestSize:
         @bpack.descriptor
         class Record:
             field_1: List[int] = bpack.field(size=4, default=0, repeat=2)
-            field_2: float = bpack.field(size=8, default=1/3)
+            field_2: float = bpack.field(size=8, default=1 / 3)
 
         assert bpack.calcsize(Record) == 16
 
@@ -337,7 +367,7 @@ class TestSize:
         @bpack.descriptor
         class Record:
             field_1: List[int] = bpack.field(size=4, default=0, repeat=2)
-            field_2: List[float] = bpack.field(size=8, default=1/3, repeat=2)
+            field_2: List[float] = bpack.field(size=8, default=1 / 3, repeat=2)
 
         assert bpack.calcsize(Record) == 24
 
@@ -345,9 +375,10 @@ class TestSize:
     def test_len_with_repeat_and_offset_01():
         @bpack.descriptor
         class Record:
-            field_1: List[int] = bpack.field(size=4, default=0, repeat=2,
-                                             offset=6)
-            field_2: List[float] = bpack.field(size=8, default=1/3, repeat=2)
+            field_1: List[int] = bpack.field(
+                size=4, default=0, repeat=2, offset=6
+            )
+            field_2: List[float] = bpack.field(size=8, default=1 / 3, repeat=2)
 
         assert bpack.calcsize(Record) == 30
 
@@ -356,19 +387,22 @@ class TestSize:
         @bpack.descriptor
         class Record:
             field_1: List[int] = bpack.field(size=4, default=0, repeat=2)
-            field_2: List[float] = bpack.field(size=8, default=1/3, repeat=2,
-                                               offset=14)
+            field_2: List[float] = bpack.field(
+                size=8, default=1 / 3, repeat=2, offset=14
+            )
 
         assert bpack.calcsize(Record) == 30
 
     @staticmethod
     def test_len_with_repeat_and_offset_03():
         with pytest.raises(bpack.descriptors.DescriptorConsistencyError):
+
             @bpack.descriptor
-            class Record:                                               # noqa
+            class Record:
                 field_1: List[int] = bpack.field(size=4, default=0, repeat=2)
-                field_2: List[float] = bpack.field(size=8, default=1/3,
-                                                   repeat=2, offset=6)
+                field_2: List[float] = bpack.field(
+                    size=8, default=1 / 3, repeat=2, offset=6
+                )
 
 
 def test_sequence_type():
@@ -388,13 +422,15 @@ def test_sequence_type():
     assert field_1.type is Sequence[int]
 
     with pytest.raises(TypeError):
+
         @bpack.descriptor
-        class Record:                                                   # noqa
+        class Record:
             field_1: Tuple[int, int] = bpack.field(size=1, repeat=2)
 
     with pytest.raises(TypeError):
+
         @bpack.descriptor
-        class Record:                                                   # noqa
+        class Record:
             field_1: Sequence = bpack.field(size=1, repeat=2)
 
 
@@ -406,6 +442,7 @@ def test_field_auto_size():
     assert bpack.calcsize(Record) == 1
 
     with pytest.warns(UserWarning):
+
         @bpack.descriptor(baseunits=EBaseUnits.BITS)
         class Record:
             field_1: bool
@@ -421,31 +458,33 @@ def test_nested_records():
 
     @bpack.descriptor
     class NestedRecord:
-        field_1: str = bpack.field(size=10, default='0123456789')
-        field_2: Record = bpack.field(size=bpack.calcsize(Record),
-                                      default=Record())
+        field_1: str = bpack.field(size=10, default="0123456789")
+        field_2: Record = bpack.field(
+            size=bpack.calcsize(Record), default_factory=Record
+        )
         field_3: int = bpack.field(size=4, default=3)
 
     record = Record()
     nested_record = NestedRecord()
 
-    assert nested_record.field_1 == '0123456789'
+    assert nested_record.field_1 == "0123456789"
     assert nested_record.field_2 == record
     assert nested_record.field_2.field_1 == record.field_1
     assert nested_record.field_2.field_2 == record.field_2
     assert nested_record.field_3 == 3
 
     with pytest.raises(bpack.descriptors.DescriptorConsistencyError):
+
         @bpack.descriptor
-        class NestedRecord:                                             # noqa
-            field_1: str = bpack.field(size=10, default='0123456789')
-            field_2: Record = bpack.field(size=bpack.calcsize(Record) + 1,
-                                          default=Record())
+        class NestedRecord:
+            field_1: str = bpack.field(size=10, default="0123456789")
+            field_2: Record = bpack.field(
+                size=bpack.calcsize(Record) + 1, default_factory=Record
+            )
             field_3: int = bpack.field(size=4, default=3)
 
 
-@pytest.mark.parametrize('baseunits',
-                         [EBaseUnits.BYTES, EBaseUnits.BITS])
+@pytest.mark.parametrize("baseunits", [EBaseUnits.BYTES, EBaseUnits.BITS])
 def test_nested_records_autosize(baseunits):
     @bpack.descriptor(baseunits=baseunits)
     class Record:
@@ -455,7 +494,7 @@ def test_nested_records_autosize(baseunits):
     @bpack.descriptor(baseunits=baseunits)
     class NestedRecord:
         field_1: int = bpack.field(size=4, default=1)
-        field_2: Record = Record()  # auto-size (bytes)
+        field_2: Record = bpack.field(default_factory=Record)  # autosize bytes
         field_3: int = bpack.field(size=4, default=4)
 
     nested_record_size = bpack.calcsize(NestedRecord, baseunits)
