@@ -8,7 +8,6 @@ import bpack
 import bpack.bs
 from bpack import T
 
-
 BITS = bpack.EBaseUnits.BITS
 BE = bpack.EByteOrder.BE
 
@@ -22,57 +21,57 @@ class SyncMarkerException(RuntimeError):
 
 
 class EEccNumber(enum.IntEnum):
-    # TODO: check "not_set"
-    not_set = 0  # contingency: reserved for ground testing or mode upgrading
-    s1 = 1
-    s2 = 2
-    s3 = 3
-    s4 = 4
-    s5_n = 5
-    s6 = 6
-    iw = 8
-    wm = 9
-    s5_s = 10
-    s1_no_ical = 11
-    s2_no_ical = 12
-    s3_no_ical = 13
-    s4_no_ical = 14
-    rfc = 15
-    test = 16
-    en_s3 = 17
-    an_s1 = 18
-    an_s2 = 19
-    an_s3 = 20
-    an_s4 = 21
-    an_s5_n = 22
-    an_s5_s = 23
-    an_s6 = 24
-    s5_n_no_ical = 25
-    s5_s_no_ical = 26
-    s6_no_ical = 27
-    en_s3_no_ical = 31
-    en = 32
-    an_s1_no_ical = 33
-    an_s3_no_ical = 34
-    an_s6_no_ical = 35
-    nc_s1 = 37
-    nc_s2 = 38
-    nc_s3 = 39
-    nc_s4 = 40
-    nc_s5_n = 41
-    nc_s5_s = 42
-    nc_s6 = 43
-    nc_ew = 44
-    nc_iw = 45
-    nc_wm = 46
+    # TODO: check "NOT_SET"
+    NOT_SET = 0  # CONTINGENCY: RESERVED FOR GROUND TESTING OR MODE UPGRADING
+    S1 = 1
+    S2 = 2
+    S3 = 3
+    S4 = 4
+    S5_N = 5
+    S6 = 6
+    IW = 8
+    WM = 9
+    S5_S = 10
+    S1_NO_ICAL = 11
+    S2_NO_ICAL = 12
+    S3_NO_ICAL = 13
+    S4_NO_ICAL = 14
+    RFC = 15
+    TEST = 16
+    EN_S3 = 17
+    AN_S1 = 18
+    AN_S2 = 19
+    AN_S3 = 20
+    AN_S4 = 21
+    AN_S5_N = 22
+    AN_S5_S = 23
+    AN_S6 = 24
+    S5_N_NO_ICAL = 25
+    S5_S_NO_ICAL = 26
+    S6_NO_ICAL = 27
+    EN_S3_NO_ICAL = 31
+    EN = 32
+    AN_S1_NO_ICAL = 33
+    AN_S3_NO_ICAL = 34
+    AN_S6_NO_ICAL = 35
+    NC_S1 = 37
+    NC_S2 = 38
+    NC_S3 = 39
+    NC_S4 = 40
+    NC_S5_N = 41
+    NC_S5_S = 42
+    NC_S6 = 43
+    NC_EW = 44
+    NC_IW = 45
+    NC_WM = 46
 
 
 class ETestMode(enum.IntEnum):
-    default = 0
-    contingency_rxm_fully_operational = 4   # 100
-    contingency_rxm_fully_bypassed = 5      # 101
-    oper = 6                                # 110
-    bypass = 7                              # 111
+    DEFAULT = 0
+    CONTINGENCY_RXM_FULLY_OPERATIONAL = 4  # 100
+    CONTINGENCY_RXM_FULLY_BYPASSED = 5  # 101
+    OPER = 6  # 110
+    BYPASS = 7  # 111
 
 
 class ERxChannelId(enum.IntEnum):
@@ -81,102 +80,104 @@ class ERxChannelId(enum.IntEnum):
 
 
 class EBaqMode(enum.IntEnum):
-    bypass = 0
-    baq3 = 3
-    baq4 = 4
-    baq5 = 5
-    fdbaq_mode_0 = 12
-    fdbaq_mode_1 = 13
-    fdbaq_mode_2 = 14
+    BYPASS = 0
+    BAQ3 = 3
+    BAQ4 = 4
+    BAQ5 = 5
+    FDBAQ_MODE_0 = 12
+    FDBAQ_MODE_1 = 13
+    FDBAQ_MODE_2 = 14
 
 
 class ERangeDecimation(enum.IntEnum):
-    x3_on_4 = 0
-    x2_on_3 = 1
-    x5_on_9 = 3
-    x4_on_9 = 4
-    x3_on_8 = 5
-    x1_on_3 = 6
-    x1_on_6 = 7
-    x3_on_7 = 8
-    x5_on_16 = 9
-    x3_on_26 = 10
-    x4_on_11 = 11
+    X3_ON_4 = 0
+    X2_ON_3 = 1
+    X5_ON_9 = 3
+    X4_ON_9 = 4
+    X3_ON_8 = 5
+    X1_ON_3 = 6
+    X1_ON_6 = 7
+    X3_ON_7 = 8
+    X5_ON_16 = 9
+    X3_ON_26 = 10
+    X4_ON_11 = 11
 
 
 @bpack.bs.decoder
 @bpack.descriptor(baseunits=BITS, byteorder=BE)
 class PacketPrimaryHeader:
-    version: T['u3'] = 0
-    packet_type: T['u1'] = 0
+    version: T["u3"] = 0
+    packet_type: T["u1"] = 0
     secondary_header_flag: bool = True
-    pid: T['u7'] = 0
-    pcat: T['u4'] = 0
-    sequence_flags: T['u2'] = 0
-    sequence_counter: T['u14'] = 0
-    packet_data_length: T['u16'] = 0
+    pid: T["u7"] = 0
+    pcat: T["u4"] = 0
+    sequence_flags: T["u2"] = 0
+    sequence_counter: T["u14"] = 0
+    packet_data_length: T["u16"] = 0
 
 
 @bpack.bs.decoder
 @bpack.descriptor(baseunits=BITS, byteorder=BE)
 class DatationService:
-    coarse_time: T['u32'] = 0
-    fine_time: T['u16'] = 0
+    coarse_time: T["u32"] = 0
+    fine_time: T["u16"] = 0
 
 
 @bpack.bs.decoder
 @bpack.descriptor(baseunits=BITS, byteorder=BE)
 class FixedAncillaryDataService:
-    sync_marker: T['u32'] = SYNK_MARKER
-    data_take_id: T['u32'] = 0
-    ecc_num: EEccNumber = bpack.field(size=8, default=EEccNumber.not_set)
+    sync_marker: T["u32"] = SYNK_MARKER
+    data_take_id: T["u32"] = 0
+    ecc_num: EEccNumber = bpack.field(size=8, default=EEccNumber.NOT_SET)
     # n. 1 bit n/a
-    test_mode: ETestMode = bpack.field(size=3, offset=73,
-                                       default=ETestMode.default)
+    test_mode: ETestMode = bpack.field(
+        size=3, offset=73, default=ETestMode.DEFAULT
+    )
     rx_channel_id: ERxChannelId = bpack.field(size=4, default=ERxChannelId.V)
-    instrument_configuration_id: T['u32'] = 0  # NOTE: the data type is TBD
+    instrument_configuration_id: T["u32"] = 0  # NOTE: the data type is TBD
 
 
 @bpack.bs.decoder
 @bpack.descriptor(baseunits=BITS, byteorder=BE)
 class SubCommunicationAncillaryDataService:
-    word_index: T['u8'] = 0
-    word_data: T['u16'] = 0
+    word_index: T["u8"] = 0
+    word_data: T["u16"] = 0
 
 
 @bpack.bs.decoder
 @bpack.descriptor(baseunits=BITS, byteorder=BE)
 class CounterService:
-    space_packet_count: T['u32'] = 0
-    pri_count: T['u32'] = 0
+    space_packet_count: T["u32"] = 0
+    pri_count: T["u32"] = 0
 
 
 @bpack.bs.decoder
 @bpack.descriptor(baseunits=BITS, byteorder=BE)
 class RadarConfigurationSupportService:
     error_flag: bool = False
-    baq_mode: EBaqMode = bpack.field(size=5, offset=3, default=EBaqMode.bypass)
-    baq_block_len: T['u8'] = 0
+    baq_mode: EBaqMode = bpack.field(size=5, offset=3, default=EBaqMode.BYPASS)
+    baq_block_len: T["u8"] = 0
     # n. 8 bits padding
-    range_decimation: ERangeDecimation = bpack.field(size=8, offset=24,
-                                                     default=0)
-    rx_gain: T['u8'] = 0
-    tx_ramp_rate: T['u16'] = 0
-    tx_pulse_start_freq: T['u16'] = 0
-    tx_pulse_length: T['u24'] = 0
+    range_decimation: ERangeDecimation = bpack.field(
+        size=8, offset=24, default=0
+    )
+    rx_gain: T["u8"] = 0
+    tx_ramp_rate: T["u16"] = 0
+    tx_pulse_start_freq: T["u16"] = 0
+    tx_pulse_length: T["u24"] = 0
     # n. 3 bits pad
-    rank: T['u5'] = bpack.field(offset=99, default=0)
-    pri: T['u24'] = 0
-    swst: T['u24'] = 0
-    swl: T['u24'] = 0
-    sas_sbb_message: T['S24'] = 0       # TODO: replace with SAS sub-record
-    ses_sbb_message: T['S24'] = 0       # TODO: replace with SES sub-record
+    rank: T["u5"] = bpack.field(offset=99, default=0)
+    pri: T["u24"] = 0
+    swst: T["u24"] = 0
+    swl: T["u24"] = 0
+    sas_sbb_message: T["S24"] = 0  # TODO: replace with SAS sub-record
+    ses_sbb_message: T["S24"] = 0  # TODO: replace with SES sub-record
 
 
 @bpack.bs.decoder
 @bpack.descriptor(baseunits=BITS, byteorder=BE, size=24)
 class RadarSampleCountService:
-    number_of_quads: T['u16'] = 0
+    number_of_quads: T["u16"] = 0
     # n. 8 bits pad
 
 
@@ -200,21 +201,23 @@ def sequential_stream_decoder(filename, maxcount=None):
     log.info(f'start decoding: "{filename}"')
     t0 = datetime.datetime.now()
 
-    primary_header_size = bpack.calcsize(PacketPrimaryHeader,
-                                         bpack.EBaseUnits.BYTES)
-    secondary_header_size = bpack.calcsize(PacketSecondaryHeader,
-                                           bpack.EBaseUnits.BYTES)
+    primary_header_size = bpack.calcsize(
+        PacketPrimaryHeader, bpack.EBaseUnits.BYTES
+    )
+    secondary_header_size = bpack.calcsize(
+        PacketSecondaryHeader, bpack.EBaseUnits.BYTES
+    )
     records = []
     packet_counter = 0
-    pbar = tqdm.tqdm(unit=' packets', desc='decoded')
-    with open(filename, 'rb') as fd, pbar:
+    pbar = tqdm.tqdm(unit=" packets", desc="decoded")
+    with open(filename, "rb") as fd, pbar:
         while fd:
             # primary header
             data = fd.read(primary_header_size)
             if len(data) == 0 or (maxcount and len(records) > maxcount):
                 break
 
-            # type: PacketPrimaryHeader
+            # type - PacketPrimaryHeader
             primary_header = PacketPrimaryHeader.frombytes(data)
             # print(primary_header)
 
@@ -228,15 +231,17 @@ def sequential_stream_decoder(filename, maxcount=None):
             data_field_size = primary_header.packet_data_length + 1
             data = fd.read(data_field_size)
 
-            # type: PacketSecondaryHeader
+            # type - PacketSecondaryHeader
             secondary_header = PacketSecondaryHeader.frombytes(
-                data[:secondary_header_size])
+                data[:secondary_header_size]
+            )
             # print(secondary_header)
 
             sync = secondary_header.fixed_ancillary_data_service.sync_marker
             if sync != SYNK_MARKER:
                 raise SyncMarkerException(
-                    f'packat count: {packet_counter + 1}')
+                    f"packat count: {packet_counter + 1}"
+                )
 
             radar_cfg = secondary_header.radar_configuration_support_service
             assert radar_cfg.error_flag is False
@@ -253,13 +258,18 @@ def sequential_stream_decoder(filename, maxcount=None):
             # update the dataframe
             r = bpack.asdict(primary_header)
             r.update(bpack.asdict(secondary_header.datation_service))
-            r.update(bpack.asdict(
-                secondary_header.fixed_ancillary_data_service))
-            r.update(bpack.asdict(
-                secondary_header.subcom_ancillary_data_service))
+            r.update(
+                bpack.asdict(secondary_header.fixed_ancillary_data_service)
+            )
+            r.update(
+                bpack.asdict(secondary_header.subcom_ancillary_data_service)
+            )
             r.update(bpack.asdict(secondary_header.counters_service))
-            r.update(bpack.asdict(
-                secondary_header.radar_configuration_support_service))
+            r.update(
+                bpack.asdict(
+                    secondary_header.radar_configuration_support_service
+                )
+            )
             r.update(bpack.asdict(secondary_header.radar_sample_count_service))
             records.append(r)
 
@@ -269,29 +279,32 @@ def sequential_stream_decoder(filename, maxcount=None):
             pbar.update()
 
     elapsed = datetime.datetime.now() - t0
-    log.info(f'decoding complete (elapsed time: {elapsed})')
+    log.info(f"decoding complete (elapsed time: {elapsed})")
 
     return pd.DataFrame(records)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     import os
     import sys
 
-    logging.basicConfig(level=logging.DEBUG,
-                        format='%(asctime)s %(levelname)s: %(message)s')
+    logging.basicConfig(
+        level=logging.DEBUG, format="%(asctime)s %(levelname)s: %(message)s"
+    )
 
     filename = (
-        'S1B_S3_RAW__0SDV_20210530T130904_20210530T130929_027134_033DC1_1AF2.SAFE/'
-        's1b-s3-raw-s-vv-20210530t130904-20210530t130929-027134-033dc1.dat'
+        "S1B_S3_RAW__0SDV_20210530T130904_20210530T130929_027134_033DC1_1AF2.SAFE/"
+        "s1b-s3-raw-s-vv-20210530t130904-20210530t130929-027134-033dc1.dat"
     )
     if not os.path.exists(filename):
-        sys.exit("""ERROR: sample product not available.
+        sys.exit(
+            """ERROR: sample product not available.
 
 You can download it as follows (scihub.copernicus.eu authentication needed):
 
 $ sentinelsat --name 'S1B_S3_RAW__0SDV_20200615T162409_20200615T162435_022046_029D76*' --download
-""")
+"""
+        )
 
     df = sequential_stream_decoder(filename)  # , maxcount=10)
     # print()
@@ -302,6 +315,4 @@ $ env PYTHONPATH=.. python3 s1isp.py
 2021-06-03 08:56:31,783 INFO: start decoding: "S1B_S3_RAW__0SDV_20210530T130904_20210530T130929_027134_033DC1_1AF2.SAFE/s1b-s3-raw-s-vv-20210530t130904-20210530t130929-027134-033dc1.dat"
 decoded: 48941 packets [00:19, 2506.83 packets/s]
 2021-06-03 08:56:51,320 INFO: decoding complete (elapsed time: 0:00:19.537022)
-
-
-"""
\ No newline at end of file
+"""
